@@ -1,11 +1,17 @@
 #' Check that an argument is an atomic vector
 #'
+#' @description
+#' For the definition of \dQuote{atomic}, see \code{\link[base]{is.atomic}}.
+#'
 #' @templateVar fn Atmoic
-#' @template checker
+#' @template x
 #' @inheritParams checkVector
+#' @template checker
 #' @family basetypes
 #' @useDynLib checkmate c_check_atomic
 #' @export
+#' @family basetypes
+#' @family atomicvector
 #' @examples
 #' testAtomic(letters, min.len = 1L, any.missing = FALSE)
 checkAtomic = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL) {
@@ -24,5 +30,6 @@ assertAtomic = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL, m
 #' @useDynLib checkmate c_check_atomic
 #' @export
 testAtomic = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL) {
-  isTRUE(.Call("c_check_atomic", x, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate"))
+  res = .Call("c_check_atomic", x, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")
+  isTRUE(res)
 }
